@@ -21,13 +21,14 @@
 */ 
  
 #include <stdio.h>
-#include <ncurses.h>
+#include <curses.h>
 #include <signal.h>
 #include <sys/soundcard.h> 
 #include <fcntl.h>
-
+#include <setjmp.h>
 #include "sounds.h"
 #include "screens.h"
 
 #define VERSION_HIGH "1"
-#define VERSION_LOW "02"
+#define VERSION_LOW "05"
+extern int a3dse, agc;
